Module blaxel.models.serverless_config
======================================

Classes
-------

`ServerlessConfig(max_scale: blaxel.types.Unset | int = <blaxel.types.Unset object>, min_scale: blaxel.types.Unset | int = <blaxel.types.Unset object>, timeout: blaxel.types.Unset | int = <blaxel.types.Unset object>)`
:   Configuration for a serverless deployment
    
    Attributes:
        max_scale (Union[Unset, int]): The minimum number of replicas for the deployment. Can be 0 or 1 (in which case
            the deployment is always running in at least one location).
        min_scale (Union[Unset, int]): The maximum number of replicas for the deployment.
        timeout (Union[Unset, int]): The timeout for the deployment in seconds
    
    Method generated by attrs for class ServerlessConfig.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `max_scale: blaxel.types.Unset | int`
    :

    `min_scale: blaxel.types.Unset | int`
    :

    `timeout: blaxel.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :